@@ -1,5 +1,9 @@
 /* epsilon-equal.c: define a error resist compare. */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* Def: HAVE_CONFIG_H */
+
 #include "types.h"
 #include "epsilon-equal.h"
 #include <math.h>
@@ -11,8 +15,10 @@
 at_bool
 epsilon_equal (at_real v1, at_real v2)
 {
-  return
-    v1 == v2		       /* Usually they'll be exactly equal, anyway.  */
-    || fabs (v1 - v2) <= REAL_EPSILON;
+  if (v1 == v2		       /* Usually they'll be exactly equal, anyway.  */
+    || fabs (v1 - v2) <= REAL_EPSILON)
+    return true;
+  else
+    return false;
 }
 
