@@ -1,7 +1,28 @@
-/* output-dxf.c: utility routines for DXF output. */
+/* output-dxf.c: utility routines for DXF output. 
+
+   Copyright (C) 1999, 2000, 2001 Dietmar Kovar
+
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public License
+   as published by the Free Software Foundation; either version 2.1 of
+   the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+   USA. */
 
 /* mail comments and suggestions to kovar@t-online.de */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* Def: HAVE_CONFIG_H */
+
 #include "types.h"
 #include "spline.h"
 #include "color.h"
@@ -619,15 +640,16 @@ static void out_splines (FILE * dxf_file, spline_list_array_type shape)
 
       spline_list_type list = SPLINE_LIST_ARRAY_ELT (shape, this_list);
       spline_type first = SPLINE_LIST_ELT (list, 0);
+      color_type curr_color = curr_color = (list.clockwise && shape.background_color != NULL)? *(shape.background_color) : list.color;
 
-      if (this_list == 0 || !COLOR_EQUAL(list.color, last_color))
+      if (this_list == 0 || !COLOR_EQUAL(curr_color, last_color))
         {
-          if (!(list.color.r==0 && list.color.g==0 && list.color.b==0) || !color_check)
+          if (!(curr_color.r==0 && curr_color.g==0 && curr_color.b==0) || !color_check)
             {
-             idx = GetIndexByRGBValue(list.color.r, list.color.g, list.color.b);
+             idx = GetIndexByRGBValue(curr_color.r, curr_color.g, curr_color.b);
              sprintf(layerstr, "C%d", idx);
              new_layer = 1;
-             last_color = list.color;
+             last_color = curr_color;
             }
     	}
       startx = START_POINT (first).x;
@@ -739,7 +761,7 @@ static void out_splines (FILE * dxf_file, spline_list_array_type shape)
              }
          }
        first_seg = 0;
-       last_color = list.color;
+       last_color = curr_color;
     }
     
     fprintf(dxf_file, "  0\nSEQEND\n  8\n0\n");
@@ -756,22 +778,22 @@ void output_layer(FILE *dxf_file,
   int i, idx;
   char layerlist[256];
   unsigned this_list;
-
+  color_type last_color = {0,0,0};
+  
   memset(layerlist, 0, sizeof(layerlist));  
   for (this_list = 0; this_list < SPLINE_LIST_ARRAY_LENGTH (shape);
        this_list++)
     {
-      color_type last_color = {0,0,0};
-
       spline_list_type list = SPLINE_LIST_ARRAY_ELT (shape, this_list);
+      color_type curr_color = (list.clockwise && shape.background_color != NULL) ? *(shape.background_color) : list.color;
 
-      if (this_list == 0 || !COLOR_EQUAL(list.color, last_color))
+      if (this_list == 0 || !COLOR_EQUAL(curr_color, last_color))
         {
-          if (!(list.color.r==0 && list.color.g==0 && list.color.b==0) || !color_check)
+          if (!(curr_color.r==0 && curr_color.g==0 && curr_color.b==0) || !color_check)
             {
-             idx = GetIndexByRGBValue(list.color.r, list.color.g, list.color.b);
+             idx = GetIndexByRGBValue(curr_color.r, curr_color.g, curr_color.b);
              layerlist[idx-1] = 1;
-             last_color = list.color;
+             last_color = curr_color;
             }
     	}
      }
@@ -827,8 +849,11 @@ void output_layer(FILE *dxf_file,
 * DXF output function.
 */
 int output_dxf12_writer(FILE* dxf_file, at_string name,
-			int llx, int lly, int urx, int ury, int dpi,
-			spline_list_array_type shape)
+			int llx, int lly, int urx, int ury, 
+			at_output_opts_type * opts,
+			spline_list_array_type shape,
+			at_msg_func msg_func, 
+			at_address msg_data)
 {
   OUT_LINE ("  0");
   OUT_LINE ("SECTION");
