@@ -1,5 +1,9 @@
 /* xfopen.c: fopen and fclose with error checking. */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* Def: HAVE_CONFIG_H */
+
 #include "xstd.h"
 #include <errno.h>
 
